==> jc-1.4.0.tar.gz: java/awt/Window__241.h <==
// final class java.awt.Window$1

// class file dependencies
// @dep_class afda194ebf6baf10 java_awt_Window__241
// @dep_class e1cb933811e6d542 java_awt_event_WindowAdapter
// @dep_class 2a7152deee1944f1 java_lang_Object

// header file dependencies
// @dep_header java_awt_event_WindowAdapter

#include "java/awt/event/WindowAdapter.h"

#ifndef _JC_java_awt_Window__241_H_
#define _JC_java_awt_Window__241_H_

// Forward structure declarations
struct _jc_java_awt_Window$object;
struct _jc_java_awt_event_WindowEvent$object;
struct _jc_java_lang_Class$object;

// Typedefs
typedef struct _jc_java_awt_Window__241$sub_refs	_jc_java_awt_Window__241$sub_refs;
typedef struct _jc_java_awt_Window__241$sub_nonrefs	_jc_java_awt_Window__241$sub_nonrefs;
typedef struct _jc_java_awt_Window__241$refs	_jc_java_awt_Window__241$refs;
typedef struct _jc_java_awt_Window__241$nonrefs	_jc_java_awt_Window__241$nonrefs;
typedef struct _jc_java_awt_Window__241$object	_jc_java_awt_Window__241$object;

typedef const struct _jc_java_awt_Window__241$vmethods	_jc_java_awt_Window__241$vmethods;
typedef const struct _jc_java_awt_Window__241$vtable	_jc_java_awt_Window__241$vtable;
typedef const struct _jc_java_awt_Window__241$vtype	_jc_java_awt_Window__241$vtype;

// Constructors
extern void _jc_java_awt_Window__241$method$_init$2efbec8a054b9293(_jc_env *, struct _jc_java_awt_Window__241$object *, struct _jc_java_awt_Window$object *);

// Virtual methods
extern void _jc_java_awt_Window__241$method$windowGainedFocus$1baa8c980f5e770f(_jc_env *, struct _jc_java_awt_Window__241$object *, struct _jc_java_awt_event_WindowEvent$object *);

// Virtual method descriptors
extern _jc_method _jc_java_awt_Window__241$method_info$windowGainedFocus$1baa8c980f5e770f;

// Virtual methods structure
struct _jc_java_awt_Window__241$vmethods {
	void	(*windowGainedFocus$1baa8c980f5e770f)(_jc_env *, struct _jc_java_awt_Window__241$object *, struct _jc_java_awt_event_WindowEvent$object *);
};

// Vtable
struct _jc_java_awt_Window__241$vtable {
	_jc_java_lang_Object$vmethods	java_lang_Object;
	_jc_java_awt_event_WindowAdapter$vmethods	java_awt_event_WindowAdapter;
	_jc_java_awt_Window__241$vmethods	java_awt_Window__241;
};

// Vtype
struct _jc_java_awt_Window__241$vtype {
	_jc_type			type;
	_jc_java_awt_Window__241$vtable	vtable;
};

// Reference instance fields (subclass)
struct _jc_java_awt_Window__241$sub_refs {
	struct _jc_java_awt_Window$object	*this;
};

// Reference instance fields (object)
struct _jc_java_awt_Window__241$refs {
    _jc_java_awt_Window__241$sub_refs	java_awt_Window__241;
    _jc_java_awt_event_WindowAdapter$sub_refs	java_awt_event_WindowAdapter;
    _jc_java_lang_Object$sub_refs	java_lang_Object;
};

// Non-reference instance fields (subclass)
struct _jc_java_awt_Window__241$sub_nonrefs {
};

// Non-reference instance fields (object)
struct _jc_java_awt_Window__241$nonrefs {
    _jc_java_lang_Object$sub_nonrefs	java_lang_Object;
    _jc_java_awt_event_WindowAdapter$sub_nonrefs	java_awt_event_WindowAdapter;
    _jc_java_awt_Window__241$sub_nonrefs	java_awt_Window__241;
};

// Object instance structure
struct _jc_java_awt_Window__241$object {
	_jc_java_awt_Window__241$refs	refs[0];
	_jc_word		lockword;
	_jc_java_awt_Window__241$vtype	*vtype;
	_jc_java_awt_Window__241$nonrefs	nonrefs;
};

// Type structure
extern _jc_java_awt_Window__241$vtype _jc_java_awt_Window__241$type;

// Array types class info structures
_JC_DECL_ARRAYS(java_awt_Window__241, type);

// java.lang.Class instance
extern struct _jc_java_lang_Class$object _jc_java_awt_Window__241$class_object;

#endif	/* _JC_java_awt_Window__241_H_ */

==> jc-1.4.5.tar.gz: java/awt/Window__241.h <==
// final class java.awt.Window$1

// class file dependencies
// @dep_class eabc430146922f3c java_awt_Window__241
// @dep_class e1cb933811e6d542 java_awt_event_WindowAdapter
// @dep_class 1c4f1fc002fc96e5 java_lang_Object

// header file dependencies
// @dep_header java_awt_event_WindowAdapter

#include "java/awt/event/WindowAdapter.h"

#ifndef _JC_java_awt_Window__241_H_
#define _JC_java_awt_Window__241_H_

// Forward structure declarations
struct _jc_java_awt_Window$object;
struct _jc_java_awt_event_WindowEvent$object;
struct _jc_java_lang_Class$object;

// Typedefs
typedef struct _jc_java_awt_Window__241$sub_refs	_jc_java_awt_Window__241$sub_refs;
typedef struct _jc_java_awt_Window__241$sub_nonrefs	_jc_java_awt_Window__241$sub_nonrefs;
typedef struct _jc_java_awt_Window__241$refs	_jc_java_awt_Window__241$refs;
typedef struct _jc_java_awt_Window__241$nonrefs	_jc_java_awt_Window__241$nonrefs;
typedef struct _jc_java_awt_Window__241$object	_jc_java_awt_Window__241$object;

typedef const struct _jc_java_awt_Window__241$vmethods	_jc_java_awt_Window__241$vmethods;
typedef const struct _jc_java_awt_Window__241$vtable	_jc_java_awt_Window__241$vtable;
typedef const struct _jc_java_awt_Window__241$vtype	_jc_java_awt_Window__241$vtype;

// Constructors
extern void _jc_java_awt_Window__241$method$_init$2efbec8a054b9293(_jc_env *, struct _jc_java_awt_Window__241$object *, struct _jc_java_awt_Window$object *) _JC_JCNI_ATTR;

// Virtual methods
extern void _jc_java_awt_Window__241$method$windowGainedFocus$1baa8c980f5e770f(_jc_env *, struct _jc_java_awt_Window__241$object *, struct _jc_java_awt_event_WindowEvent$object *) _JC_JCNI_ATTR;

// Virtual method descriptors
extern _jc_method _jc_java_awt_Window__241$method_info$windowGainedFocus$1baa8c980f5e770f;

// Virtual methods structure
struct _jc_java_awt_Window__241$vmethods {
	void	(*windowGainedFocus$1baa8c980f5e770f)(_jc_env *, struct _jc_java_awt_Window__241$object *, struct _jc_java_awt_event_WindowEvent$object *) _JC_JCNI_ATTR;
};

// Vtable
struct _jc_java_awt_Window__241$vtable {
	_jc_java_lang_Object$vmethods	java_lang_Object;
	_jc_java_awt_event_WindowAdapter$vmethods	java_awt_event_WindowAdapter;
	_jc_java_awt_Window__241$vmethods	java_awt_Window__241;
};

// Vtype
struct _jc_java_awt_Window__241$vtype {
	_jc_type			type;
	_jc_java_awt_Window__241$vtable	vtable;
};

// Reference instance fields (subclass)
struct _jc_java_awt_Window__241$sub_refs {
	struct _jc_java_awt_Window$object	*this;
};

// Reference instance fields (object)
struct _jc_java_awt_Window__241$refs {
    _jc_java_awt_Window__241$sub_refs	java_awt_Window__241;
    _jc_java_awt_event_WindowAdapter$sub_refs	java_awt_event_WindowAdapter;
    _jc_java_lang_Object$sub_refs	java_lang_Object;
};

// Non-reference instance fields (subclass)
struct _jc_java_awt_Window__241$sub_nonrefs {
};

// Non-reference instance fields (object)
struct _jc_java_awt_Window__241$nonrefs {
    _jc_java_lang_Object$sub_nonrefs	java_lang_Object;
    _jc_java_awt_event_WindowAdapter$sub_nonrefs	java_awt_event_WindowAdapter;
    _jc_java_awt_Window__241$sub_nonrefs	java_awt_Window__241;
};

// Object instance structure
struct _jc_java_awt_Window__241$object {
	_jc_java_awt_Window__241$refs	refs[0];
	_jc_word		lockword;
	_jc_java_awt_Window__241$vtype	*vtype;
	_jc_java_awt_Window__241$nonrefs	nonrefs;
};

// Type structure
extern _jc_java_awt_Window__241$vtype _jc_java_awt_Window__241$type;

// Array types class info structures
_JC_DECL_ARRAYS(java_awt_Window__241, type);

// java.lang.Class instance
extern struct _jc_java_lang_Class$object _jc_java_awt_Window__241$class_object;

#endif	/* _JC_java_awt_Window__241_H_ */
